<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\SettingsModel;
use App\Models\User;
use App\Models\Product;
use App\Models\AmountDistributionHistory;
use App\Models\Orders;
use App\Models\TransactionTrack;
use App\Models\CountryModel;
use Validator,DB;

class CoustomerController extends Controller
{
    //
    public function index(){
        $page_heading = "Dashbaord";
        
        $settings = SettingsModel::first();
        $daily_ticket = Product::where(['product_type'=>'daily'])->orderBy('id','desc')->get()->first();
        $monthly_ticket = Product::where(['product_type'=>'monthly'])->orderBy('id','desc')->get()->first();
        
        $last_transaction_history = TransactionTrack::where(['user_id'=>Auth::user()->id])->orderBy('id','desc')->limit(1)->get()->first();
        $last_transaction_time = $last_transaction_history->created_at??gmdate('Y-m-d H:i:s');
        return view('frond.dashboard',compact('page_heading','settings','daily_ticket','monthly_ticket','last_transaction_time'));
    }
    
    public function edit_profile(REQUEST $request){
        $page_heading = "Edit Profile";
        $country_list = CountryModel::where(['active'=>1])->get();
        return view('frond.edit_profile',compact('page_heading','country_list'));
    }
    public function update_profile(REQUEST $request){
        $status = "0";
        $message = "";
        $o_data = [];
        $errors = [];
        $redirectUrl = '';

        $validator = Validator::make($request->all(), [
            'first_name' => 'required',
            'last_name' => 'required',
            'dial_code' => 'required',
            'phone'     =>'required',
        ]);
        
        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        } else {
            
            $phone_check = User::where(['dial_code'=>$request->dial_code,'phone'=>$request->phone])->where('id','!=',Auth::user()->id)->get()->count();
            if($phone_check > 0){
                $status = "0";
                $message= "Mobilenumber already registred";
                $errors['phone'] = $message;
                echo json_encode(['status' => $status, 'message' => $message, 'errors' => $errors]);
                exit;
            }
            
            $user =  User::find(Auth::user()->id);
            $user->first_name = $request->first_name;
            $user->last_name = $request->last_name;
            
            $user->dial_code = $request->dial_code;
            $user->phone     = $request->phone;
            $user->name      = $user->first_name." ".$user->last_name;
            
            $user->updated_at = gmdate('Y-m-d H:i:s');
            $user->save();

            if($user->id){
                $status = "1";
                $message = "You have successfully updated your profile";
                
            }else{
                $message = "Faild to update. Please try again after sometimes";
            }
        }
        echo json_encode(['status' => $status, 'message' => $message, 'errors' => $errors,'redirectUrl'=>$redirectUrl]);
    }
    
    public function commissions(REQUEST $request){
        $page_heading = "Commissions";
        $list=AmountDistributionHistory::where(['user_id'=>Auth::user()->id])->orderBy('id','desc');
        if($request->transaction_hash){
            $list= $list->where(['transaction_hash'=>$request->transaction_hash]);
        }
        if($request->transaction_type){
            $list= $list->where(['type'=>$request->transaction_type]);
        }
        
        $list=$list->paginate(10);
        return view('frond.commission_distribution_list',compact('page_heading','list'));
    }
    public function my_tickets(REQUEST $request){
        $page_heading = "My Tickets";
        $list=Orders::where(['user_id'=>Auth::user()->id])->OrderBy('id','desc');
        if($request->search_key){
            $list= $list->where(['ticket_number'=>$request->search_key]);
        }
        if($request->drow_date){
            $list= $list->whereDate('drow_date',date('Y-m-d',strtotime($request->drow_date)));
        }
        $list=$list->paginate(10);
        return view('frond.order_list',compact('page_heading','list'));
    }
    
    public function check_new_transaction(REQUEST $request){
        $status = "0";
        $message = "";
        $errors = [];
        $o_data = [];
        $check = TransactionTrack::where(['user_id'=>Auth::user()->id,'amount'=>rtrim($request->amount,".")])->where('created_at','>',date('Y-m-d H:i:s',strtotime($request->last_transaction_time)))->get();
        if($check->count() > 0){
            $status = "1";
            $message = "Your transaction successfully received on backend. Your tickets will be processed soon and will be available in my tickets list soon";
            if($request->type == "membership"){
                $status = "3";
                $message = "Your transaction successfully received on backend. Your membership plan will be alloted soon";
            }
        }else{
            $message = "no transaction received yet";
        }
        echo json_encode([
            'status' => $status, 'message' => $message,'errors'=>$errors,'oData'=>$o_data
        ]);
    }
    public function logout(){
        session()->pull("user_id");
        Auth::logout();
        return redirect()->route('guest.home_page');
    }
    
    public function update_profile_image(REQUEST $request){
        $status = "0";
        $message = "";
        $o_data = [];
        $errors = [];
        $redirectUrl = '';

        $validator = Validator::make($request->all(), [
            'user_image' => 'required|mimes:jpg,jpeg,png'
        ]);
        
        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        } else {
            
            
            $user =  User::find(Auth::user()->id);
            if($file = $request->file("user_image")){
                
                $file_name = time().uniqid().".".$file->getClientOriginalExtension();
                $file->storeAs(config('global.user_image_upload_dir'),$file_name,config('global.upload_bucket'));
                $user->user_image = $file_name;
            
            
                $user->updated_at = gmdate('Y-m-d H:i:s');
                $user->save();
    
                if($user->id){
                    $status = "1";
                    $message = "You have successfully updated your profile image";
                    
                }else{
                    $message = "Faild to update. Please try again after sometimes";
                }
            }else{
                $message = "Faild to update. Please try again after sometimes";
            }
        }
        echo json_encode(['status' => $status, 'message' => $message, 'errors' => $errors,'redirectUrl'=>$redirectUrl]);
    }
    
    public function change_password(Request $request)
    {
        if ($request->isMethod('post')) {
            $status = "0";
            $message = "";
            $errors = [];
            $validator = Validator::make($request->all(),
                [
                    'cur_pswd' => 'required',
                    'new_pswd' => 'required',
                ],
                [
                    'cur_pswd.required' => 'Current password required',
                    'new_pswd.required' => 'New password required',
                ]
            );
            if ($validator->fails()) {
                $status = "0";
                $message = "Validation error occured";
                $errors = $validator->messages();
            } else {
                $cur_pswd = $request->cur_pswd;
                $new_pswd = $request->new_pswd;
                $user_id = Auth::user()->id;
                if(Auth::attempt(['id' => $user_id, 'password' => $cur_pswd])) {
                    $up['password'] = bcrypt($new_pswd);
                    $up['updated_on'] =gmdate('Y-m-d H:i:s');
                    if(User::update_password($user_id,$new_pswd)){
                        $status = "1";
                        $message = "Password successfully changed";
                        $errors = '';
                    }else{
                        $status = "0";
                        $message = "Unable to change password. Please try again later";
                        $errors = '';
                    }
                }else{
                    $status = "0";
                    $message = "Invalid Current Password";
                    $errors = '';
                }

            }
            echo json_encode(['status' => $status, 'message' => $message, 'errors' => $errors]);die();
        }else{
            $page_heading = "Change Password";
            return view("frond.change_password", compact('page_heading'));
        }

    }
    public function view_user_referls(REQUEST $request){
        $page_heading = "View Referrals";
        $list = User::where('role',3)->where(['refered_by'=>Auth::user()->id])->orderBy('id','desc');
        if($request->status){
            $list = $list->where('active',$request->status);
        }
        if($request->from_date){
            $list = $list->whereDate('created_at','>=',date('Y-m-d',strtotime($request->from_date)));
        }
        if($request->to_date){
            $list = $list->whereDate('created_at','<=',date('Y-m-d',strtotime($request->to_date)));
        }
        if($request->search_key){
            $list = $list->whereRaw("name ilike '%".strtolower($request->search_key)."%'");
        }
        $list = $list->paginate(10);

        return view('frond.referel_list',compact('page_heading','list'));
    }
}
