<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Orders;
use App\Models\Product;
use Validator,DB;
use Illuminate\Support\Facades\Auth;

class OrderController extends Controller
{
    //
    public function daily(REQUEST $request){
        $page_heading = "Daily Ticket Purchases";
        $list=Orders::with(['user'])->where(['product_type'=>'daily'])->OrderBy('id','desc');
        if($request->search_key){
            $list= $list->where(['ticket_number'=>$request->search_key]);
        }
        if($request->drow_date){
            $list= $list->whereDate('drow_date',date('Y-m-d',strtotime($request->drow_date)));
        }else{
            $list= $list->whereDate('drow_date',date('Y-m-d'));
        }
        if($request->search_name){
            $name = $request->search_name;
            $list = $list->whereHas('user',function($q) use($name){
                $q->whereRaw("name ilike '%".$name."%'");
            });
        }
        if($request->search_wallet_address){
            $search_wallet_address = $request->search_wallet_address;
            $list = $list->whereHas('user',function($q) use($search_wallet_address){
                $q->where(['wallet_address'=>$search_wallet_address]);
            });
        }
        $list=$list->paginate(10);
        return view('admin.orders.daily_list',compact('page_heading','list'));
    }
    public function monthly(REQUEST $request){
        $page_heading = "Monthly Ticket Purchases";
        $list=Orders::with(['user'])->where(['product_type'=>'monthly'])->OrderBy('id','desc');
        if($request->search_key){
            $list= $list->where(['ticket_number'=>$request->search_key]);
        }
        if($request->drow_date){
            $dr_date = $request->drow_date;
            $list= $list->whereDate('drow_date',date('Y-m-d',strtotime($request->drow_date)));
        }else{
            $product = Product::where(['product_type'=>'monthly'])->get()->first();
            $drow_date = $product->drow_date;
            $d = date('d');
            
            if($d < $drow_date){
                //$dr_date = date('Y')."-".date('m')."-".$drow_date;
                $dr_date = $drow_date."-".date('m')."-".date('Y');
            }else{
                //$dr_date = date('Y')."-".(date('m') + 1)."-".$drow_date;
                $dr_date = $drow_date."-".(date('m') + 1)."-".date('Y');
            }
            $list= $list->whereDate('drow_date',date('Y-m-d',strtotime($dr_date)));
        }
        
        if($request->search_name){
            $name = $request->search_name;
            $list = $list->whereHas('user',function($q) use($name){
                $q->whereRaw("name ilike '%".$name."%'");
            });
        }
        if($request->search_wallet_address){
            $search_wallet_address = $request->search_wallet_address;
            $list = $list->whereHas('user',function($q) use($search_wallet_address){
                $q->where(['wallet_address'=>$search_wallet_address]);
            });
        }
        $list=$list->paginate(10);
        return view('admin.orders.monthly_list',compact('page_heading','list','dr_date'));
    }
    public function make_winner(REQUEST $request, $id)
    {
        $status = "0";
        $message = "";

        

        $category_data = Orders::where(['id' => $id])->first();

        if ($category_data) {
            Orders::where(['id' => $id])->update(['is_winner'=>1]);
            $message = "Winner alloted successfully";
            $status = "1";
            exec("php ".base_path()."/artisan app:lotery-winner-mail ".$id." > /dev/null 2>&1 & ");
            exec("php ".base_path()."/artisan app:winner-price-distribution ".$id." > /dev/null 2>&1 & ");
        } else {
            $message = "Invalid Order Data data";
        }

        echo json_encode([
            'status' => $status, 'message' => $message
        ]);
    }
    public function add_winner(REQUEST $request)
    {
        $status = "0";
        $message = "";
        $id=$request->lot_id;
        $price_postion = $request->price_postion;
        
        if($id){
            $category_data = Orders::with(['product'])->where(['id' => $id])->first();
    
            if ($category_data) {
                $price = $category_data->product->{'price_'.$price_postion};
                if($price > 0){
                    Orders::where(['id' => $id])->update(['is_winner'=>1,'winner_position'=>$price_postion,'winner_price'=>$price]);
                    $message = "Winner alloted successfully";
                    $status = "1";
                    exec("php ".base_path()."/artisan app:lotery-winner-mail ".$id." > /dev/null 2>&1 & ");
                    exec("php ".base_path()."/artisan app:winner-price-distribution ".$id." > /dev/null 2>&1 & ");
                }else{
                    $message = "price value not added for this position";
                }
            } else {
                $message = "Invalid Order Data data";
            }
        }else{
            $message = "invalid id passed";
        }

        echo json_encode([
            'status' => $status, 'message' => $message
        ]);
    }
    public function assign_multi_winner(REQUEST $request)
    {
        $status = "0";
        $message = "";
        $ids=$request->all_in_one;
        $price_postion = $request->price_postion;
        
        if($ids){
            foreach($ids as $id){
                $category_data = Orders::with(['product'])->where(['id' => $id])->first();
        
                if ($category_data) {
                    $price = $category_data->product->{'price_'.$price_postion};
                    if($price > 0){
                        Orders::where(['id' => $id])->update(['is_winner'=>1,'winner_position'=>$price_postion,'winner_price'=>$price]);
                        $message = "Winner alloted successfully";
                        $status = "1";
                        exec("php ".base_path()."/artisan app:lotery-winner-mail ".$id." > /dev/null 2>&1 & ");
                        exec("php ".base_path()."/artisan app:winner-price-distribution ".$id." > /dev/null 2>&1 & ");
                    }else{
                        $message = "price value not added for this position";
                    }
                }
            }
        }else{
            $message = "please select atleast one item";
        }

        echo json_encode([
            'status' => $status, 'message' => $message
        ]);
    }
    public function generate_random_winner(REQUEST $request){
        $status = "0";
        $message = "";
        $o_data = [];
        $errors = [];
        $o_data['redirect'] =  route('admin.list_orders');
        if($request->lotery_type == 'monthly'){
            $o_data['redirect'] =  route('admin.list_orders_monthly');
        }
        $validator = Validator::make($request->all(),
            [
                'lotery_drow_date' => 'required'
            ]
        );
        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        } else {
            $drow_date = $request->lotery_drow_date;
            
            $drow_date = date('Y-m-d',strtotime($drow_date));
            
            $chek_already_assigned = Orders::Where(['product_type'=>$request->lotery_type,'is_winner'=>1])->whereDate('drow_date','=',$drow_date)->get();
            if($chek_already_assigned->count() > 0){
                $message = "winner already assigned";
            }else{
                $lotery = Orders::Where(['product_type'=>$request->lotery_type])->whereDate('drow_date','=',$drow_date)->inRandomOrder()->get()->first();
                if($lotery){
                     Orders::where(['id' => $lotery->id])->update(['is_winner'=>1]);
                     exec("php ".base_path()."/artisan app:lotery-winner-mail ".$lotery->id." > /dev/null 2>&1 & ");
                    $message = "Winner alloted successfully";
                    $status = "1";
                }else{
                    $message = "No purchases made on this date";
                }
            }

        }
        echo json_encode(['status' => $status, 'message' => $message, 'errors' => $errors,'oData'=>$o_data]);
        exit;
        
    }
}
