<?php

use App\Http\Middleware\IsAdmin;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Artisan;


Route::get('/clear', function () {
    Artisan::call('optimize');
    Artisan::call('optimize:clear');
    Artisan::call('cache:clear');
    Artisan::call('config:clear');
    Artisan::call('config:cache');
    Artisan::call('view:clear');
    dd('cleared');
});


Route::post('/response_hook','App\Http\Controllers\PaymentController@response_hook');
Route::get('/response_hook','App\Http\Controllers\PaymentController@response_hook');

Route::get('/admin', 'App\Http\Controllers\admin\LoginController@login')->name('admin.login');
Route::post('admin/check_login', 'App\Http\Controllers\admin\LoginController@check_login')->name('admin.check_login');


// ------------ Admin Routes -------------

Route::namespace('App\Http\Controllers\admin')->prefix('admin')->middleware('admin')->name('admin.')->group(function () {

    Route::get('access-restricted', 'AdminUserController@access_restricted')->name('restricted_page');
    Route::get('dashboard', 'DashboardController@dashboard')->name('dashboard');
    Route::get('change-password', 'AdminController@changePassword')->name('change.password');
    Route::post('change-password', 'AdminController@changePasswordSave')->name('change.password.save');
    Route::get('logout', 'LoginController@logout')->name('logout');

    Route::match(array('GET', 'POST'), 'change_password', 'UsersController@change_password');
    Route::match(array('GET', 'POST'), 'change_user_password', 'UsersController@change_user_password');

    Route::resource("admin_user_designation", "AdminUserDesignation");

    Route::resource("admin_users", "AdminUserController");
    Route::post("admin_users/change_status", "AdminUserController@change_status");
    Route::post("admin_users/verify", "AdminUserController@verify");
    Route::get("admin_users/update_permission/{id}", "AdminUserController@update_permission");
    Route::post("save_privilege", "AdminUserController@save_privilege");

    // user roles
    Route::get('user_roles/list', 'UserRoleController@index')->name('user_roles.list');
    Route::get('user_roles/create', 'UserRoleController@create')->name('user_roles.create');
    Route::get('user_roles/edit/{id}', 'UserRoleController@create')->name('user_roles.edit');
    Route::post('user_roles/submit', 'UserRoleController@submit')->name('user_roles.submit');
    Route::delete('user_roles/delete/{id}', 'UserRoleController@delete')->name('user_roles.delete');
    Route::post('user_roles/get_role_list', 'UserRoleController@getroleList')->name('getRoleList');
    Route::post('user_roles/status_change/{id}', 'UserRoleController@change_status')->name('user_roles.status_change');


    Route::get('cms_pages', 'PagesController@index')->name('cms_pages');
    Route::get('page/create', 'PagesController@create')->name('cms_pages.add');
    Route::get('page/edit/{id}', 'PagesController@edit')->name('cms_pages.edit');
    Route::post('page/save', 'PagesController@save')->name('cms_pages.save');
    Route::delete('page/delete/{id}', 'PagesController@delete')->name('cms_pages.delete');
    Route::get('contact_details', 'PagesController@contact_details')->name('contact_details');
    Route::post("contact_us_setting_store", "PagesController@contact_us_setting_store")->name('contact_us_setting_store');
    Route::get('settings', 'PagesController@settings');
    Route::post("setting_store", "PagesController@setting_store")->name('setting_store');

    //FAQ
    Route::get("faq", "FaqController@index");
    Route::match(array('GET', 'POST'), 'faq/create', 'FaqController@create');
    Route::get("faq/edit/{id}", "FaqController@edit");
    Route::post("faq/update", "FaqController@update");
    Route::delete("faq/delete/{id}", "FaqController@delete");

    Route::get("help", "ContactQueryController@index");
    Route::match(array('GET', 'POST'), 'help/create', 'HelpController@create');
    Route::get("help/edit/{id}", "HelpController@edit");
    Route::post("help/update", "HelpController@update");
    Route::delete("help/delete/{id}", "HelpController@delete");
    

    Route::get("products", "ProductController@index")->name('list_product');
    Route::get("products/create", "ProductController@create")->name('create_product');
    Route::get("products/create/{id}", "ProductController@create")->name('edit_product');
    Route::Post("products/save", "ProductController@save")->name('save_product');
    Route::delete("products/delete/{id}", "ProductController@delete")->name('delete_product');

    Route::get("customers", "CustomerController@index")->name('list_customers');
    Route::delete("customers/delete/{id}", "CustomerController@delete")->name('delete_customer');
    Route::get("customers/view_user_referls/{id}", "CustomerController@view_user_referls")->name('view_user_referls');

    
    
    
    Route::get("daily_ticket_purchases", "OrderController@daily")->name('list_orders');
    Route::get("monthly_ticket_purchases", "OrderController@monthly")->name('list_orders_monthly');
    Route::delete("orders/make_winner/{id}", "OrderController@make_winner")->name('make_winner');
    Route::post("generate_random_winner", "OrderController@generate_random_winner")->name('generate_random_winner');
    
    Route::post("orders/add_winner", "OrderController@add_winner")->name('add_winner');
    Route::post("orders/assign_multi_winner", "OrderController@assign_multi_winner")->name('assign_multi_winner');

    Route::get("report_daily_tickets", "ReportController@report_daily_tickets")->name('report_daily_tickets');
    Route::get("report_monthly_tickets", "ReportController@report_monthly_tickets")->name('report_monthly_tickets');
    
    Route::get("report_daily_ticket_winners", "ReportController@report_daily_ticket_winners")->name('report_daily_ticket_winners');
    Route::get("report_monthly_ticket_winners", "ReportController@report_monthly_ticket_winners")->name('report_monthly_ticket_winners');
    
    Route::get("report_customers", "ReportController@report_customers")->name('report_customers');
    
    Route::get("transactions", "TransactionController@index")->name('list_transactions');
    Route::delete("transactions/allote_membership/{id}", "TransactionController@allote_membership")->name('allote_membership');
    
    Route::delete("transactions/allote_daily_lotery/{id}", "TransactionController@allote_daily_lotery")->name('allote_daily_lotery');
    Route::delete("transactions/allote_monthly_lotery/{id}", "TransactionController@allote_monthly_lotery")->name('allote_monthly_lotery');
    
    Route::get("commission_distribution", "TransactionController@amount_distribution")->name('commission_distribution');
    Route::delete("commission_distribution/reintiate_commission/{id}", "TransactionController@reintiate_commission")->name('reintiate_commission');
    
    Route::get("winner_distribution", "TransactionController@winner_distribution")->name('winner_distribution');
    Route::delete("winner_distribution/reintiate_commission/{id}", "TransactionController@reintiate_winner_price")->name('reintiate_winner_price');

});


// ------------ Vendor Main Routes -------------

Route::get('/vendor', 'App\Http\Controllers\vendor\LoginController@login')->name('vendor.login');
Route::post('vendor/check_login', 'App\Http\Controllers\vendor\LoginController@check_login')->name('vendor.check_login');
Route::get('/forgot-password', 'App\Http\Controllers\vendor\LoginController@forgotpassword')->name('vendor.forgot');
Route::post('vendor/check_user', 'App\Http\Controllers\vendor\LoginController@check_user')->name('vendor.check_user');


// ------------ Vendor Sub Routes -------------


Route::namespace('App\Http\Controllers\vendor')->prefix('vendor')->middleware('vendor')->name('vendor.')->group(function () {

    Route::get('logout', 'LoginController@logout')->name('logout');

    // If vendor is verified
    Route::middleware('is_vendor_verified')->group(function () {

        Route::match(array('GET', 'POST'), 'change_password', 'UsersController@change_password');
        Route::get('dashboard', 'DashboardController@dashboard')->name('dashboard');

    });

});

// ----------------------------------


Route::namespace('App\Http\Controllers')->name('guest.')->group(function () {
    Route::get('/', 'HomeController@index')->name('home_page');
    Route::get('register', 'HomeController@register')->name('register_page');
    Route::post('signup', 'HomeController@signup')->name('signup');
    Route::post('login', 'HomeController@login')->name('login');
    Route::get('terms_and_condtions', 'HomeController@terms_and_condtions')->name('terms_and_condtions');
    Route::get('privacy_policy', 'HomeController@privacy_policy')->name('privacy_policy');
    Route::get('faq', 'HomeController@faq')->name('faq');
});

Route::namespace('App\Http\Controllers')->prefix('customer')->middleware('customer')->name('customer.')->group(function () {
    Route::get('logout', 'CoustomerController@logout')->name('logout');
    Route::get('dashbaord', 'CoustomerController@index')->name('dashbaord');
    Route::get('commissions', 'CoustomerController@commissions')->name('commissions');
    Route::get('my_tickets', 'CoustomerController@my_tickets')->name('my_tickets');
    Route::post('check_new_transaction', 'CoustomerController@check_new_transaction')->name('check_new_transaction');
    Route::get('edit_profile', 'CoustomerController@edit_profile')->name('edit_profile');
    Route::post('update_profile', 'CoustomerController@update_profile')->name('update_profile');
    
    Route::post('update_profile_image', 'CoustomerController@update_profile_image')->name('update_profile_image');
    Route::get('change_password', 'CoustomerController@change_password')->name('get_change_password');
    Route::post('change_password', 'CoustomerController@change_password')->name('change_password');
    Route::get("view_user_referls", "CoustomerController@view_user_referls")->name('view_user_referls');
    
});